@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2009, Shawn Rutledge <shawn.t.rutledge@gmail.com>
  * Copyright (C) 2009, Pino Toscano <pino@kde.org>
+ * Copyright (C) 2021, Albert Astals Cid <aacid@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +31,7 @@ class ThumbnailsDock : public AbstractInfoDock
     Q_OBJECT
 
 public:
-    ThumbnailsDock(QWidget *parent = nullptr);
+    explicit ThumbnailsDock(QWidget *parent = nullptr);
     ~ThumbnailsDock() override;
 
     void documentClosed() override;
